package net.eciz.evosciencia.screen;

import net.eciz.evosciencia.model.Avatar;
import net.eciz.evosciencia.model.DPADElement;
import net.eciz.evosciencia.values.EvoScienciaValues;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.maps.tiled.TiledMap;
import com.badlogic.gdx.maps.tiled.TiledMapTileLayer;
import com.badlogic.gdx.maps.tiled.TmxMapLoader;
import com.badlogic.gdx.maps.tiled.renderers.OrthogonalTiledMapRenderer;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;

public class GameScreen implements Screen, EvoScienciaValues {
	
	private Skin tmpSkin;
	
	/**
	 * DPAD
	 */
	private SpriteBatch dpadBatch;
	private DPADElement dpadUp;
	private DPADElement dpadDown;
	private DPADElement dpadLeft;
	private DPADElement dpadRight;
	
	private Stage stage;
	private Table table;
	private TextureAtlas atlas;
	private Skin skin;
	private Button button;
	
	private TiledMap map;
	private OrthogonalTiledMapRenderer renderer;
	private OrthographicCamera camera;
	
	private Avatar avatar;

	@Override
	public void render(float delta) {
		Gdx.gl.glClearColor(255, 255, 255, 1);
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
		
		camera.position.set(avatar.getX() + avatar.getWidth() / 2, avatar.getY() + avatar.getHeight() / 2, 0);
		camera.update();
		
		renderer.setView(camera);
		renderer.render();
		
		renderer.getSpriteBatch().begin();
		avatar.draw(renderer.getSpriteBatch());
		renderer.getSpriteBatch().end();
		
//		dpadBatch.begin();
//		dpadUp.draw(dpadBatch);
//		dpadDown.draw(dpadBatch);
//		dpadLeft.draw(dpadBatch);
//		dpadRight.draw(dpadBatch);
//		dpadBatch.end();
//		
//		Table.drawDebug(stage);
//		stage.act(delta);
//		stage.draw();
	}

	@Override
	public void resize(int width, int height) {
		camera.viewportWidth = width/4;
		camera.viewportHeight = height/4;
	}

	@Override
	public void show() {
		
		// Loading tiled map
		map = new TmxMapLoader().load("maps/outsideMap.tmx");
		// Initialize camera
		camera = new OrthographicCamera();
		// Initialize renderer
		renderer = new OrthogonalTiledMapRenderer(map);
		// Initialize avatar
		avatar = new Avatar(new Sprite(new Texture("graphics/avatar_test.png")), (TiledMapTileLayer) map.getLayers().get(0));
		// Set avatar position
		TiledMapTileLayer tiledMapTileLayer = (TiledMapTileLayer) map.getLayers().get(0);
		avatar.setPosition((tiledMapTileLayer.getWidth()*tiledMapTileLayer.getTileWidth())/2,
				(tiledMapTileLayer.getHeight()*tiledMapTileLayer.getTileHeight())/2);
//		
//		// Initializing dpad elements
//		dpadBatch = new SpriteBatch();
//		dpadUp = new DPADElement( new Sprite(new Texture("ui/dpad_up.png")), avatar );
//		dpadDown = new DPADElement( new Sprite(new Texture("ui/dpad_down.png")), avatar );
//		dpadLeft = new DPADElement( new Sprite(new Texture("ui/dpad_left.png")), avatar );
//		dpadRight = new DPADElement( new Sprite(new Texture("ui/dpad_right.png")), avatar );
//		
//		// Positioning dpad elements
//		int height = Gdx.graphics.getHeight();
//		int btnSize = height/10;
//		
//		dpadUp.setSize(btnSize, btnSize);
//		dpadDown.setSize(btnSize, btnSize);
//		dpadLeft.setSize(btnSize, btnSize);
//		dpadRight.setSize(btnSize, btnSize);
//		
//		dpadUp.setPosition(btnSize + 20, ( ( btnSize* 2 ) + ( btnSize/2 ) + 20 ));
//		dpadDown.setPosition(btnSize + 20, ( ( btnSize ) - ( btnSize/2 ) + 20 ));
//		dpadLeft.setPosition(20, ( ( btnSize/2 ) + btnSize + 20 ));
//		dpadRight.setPosition(20 + ( btnSize * 2), ( ( btnSize/2 ) + btnSize + 20 ));
//		
		// Setting up inputs
//		Gdx.input.setInputProcessor(map);
//		Gdx.input.setInputProcessor(dpadUp);
//		Gdx.input.setInputProcessor(dpadDown);
//		Gdx.input.setInputProcessor(dpadLeft);
//		Gdx.input.setInputProcessor(dpadRight);
//		
//		stage = new Stage();
//		
//		Gdx.input.setInputProcessor(stage);
//		
//		atlas = new TextureAtlas(BUTTON_PACK);
//		skin = new Skin(Gdx.files.internal(JSON_BUTTON_STYLE), atlas);
//		
//		table = new Table(tmpSkin);
//		table.setBounds(0, 0 , Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
//		
//		tmpSkin = new Skin();
//		tmpSkin.add("button", new Texture("ui/dpad_up.png"));
//		
//		ButtonStyle buttonStyle = new ButtonStyle();
//		
//		button = new Button(buttonStyle);
//		button.setBackground(tmpSkin.getDrawable("button"));
//		
//		button.addListener(new ClickListener() {
//			@Override
//			public void clicked(InputEvent event, float x, float y) {
//				System.out.println( "CLICKED" );
//			}
//		});
//		
//		table.add(button);
//		
//		table.debug();
//		stage.addActor(table);
	}

	@Override
	public void hide() {
		
	}

	@Override
	public void pause() {
		
	}

	@Override
	public void resume() {
		
	}

	@Override
	public void dispose() {
		map.dispose();
		renderer.dispose();
		avatar.getTexture().dispose();
		dpadBatch.dispose();
		stage.dispose();
		atlas.dispose();
		skin.dispose();
	}

}
