package net.eciz.evosciencia.screen;

import net.eciz.evosciencia.values.EvoScienciaValues;

import com.badlogic.gdx.Game;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;

public class MainMenu implements Screen, EvoScienciaValues {

	private Texture texture;
	private SpriteBatch batch;
	private Sprite background;
	
	private Stage stage;
	private TextureAtlas atlas;
	private Skin skin;
	private Table table;
	
	// Buttons
	private TextButton btnStart;
	private TextButton btnOptions;
	private TextButton btnAboutUs;
	private TextButton btnExit;
	
	// Fonts

	@Override
	public void render(float delta) {
		Gdx.gl.glClearColor(255, 255, 255, 1);
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
		
//		Table.drawDebug(stage);
		
		batch.begin();
		background.draw(batch);
		batch.end();
		
		stage.act(delta);
		stage.draw();
	}

	@Override
	public void resize(int width, int height) {

	}

	@Override
	public void show() {
		
		batch = new SpriteBatch();
		
		texture = new Texture(SPLASH_IMAGE);
		
		background = new Sprite(texture);
		background.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
		
		stage = new Stage();
		
		Gdx.input.setInputProcessor(stage);
		
		atlas = new TextureAtlas(BUTTON_PACK);
		skin = new Skin(Gdx.files.internal(JSON_BUTTON_STYLE), atlas);
		
		table = new Table(skin);
		table.setBounds(0, Gdx.graphics.getHeight() * (1/3) , Gdx.graphics.getWidth(), Gdx.graphics.getHeight()/4);
		
		btnStart = new TextButton("Play", skin);
		btnOptions = new TextButton("Options", skin);
		btnAboutUs = new TextButton("About Us", skin);
		btnExit = new TextButton("Exit", skin);
		
		btnStart.pad(10);
		btnOptions.pad(10);
		btnAboutUs.pad(10);
		btnExit.pad(10);
		
		btnStart.addListener(new ClickListener(){
			@Override
			public void clicked(InputEvent event, float x, float y) {
//				((Game) Gdx.app.getApplicationListener()).setScreen(new SaveDataScreen());
				((Game) Gdx.app.getApplicationListener()).setScreen(new GameScreen());
			}
		});
		
		btnExit.addListener(new ClickListener(){
			@Override
			public void clicked(InputEvent event, float x, float y) {
				Gdx.app.log(EvoScienciaValues.APP_NAME, "Game exit");
				Gdx.app.exit();
			}
		});
		
		table.add(btnStart);
		table.add(btnOptions);
		table.add(btnAboutUs);
		table.add(btnExit);
		table.getCell(btnExit).spaceBottom(10);
		
		table.debug();
		stage.addActor(table);
	}

	@Override
	public void hide() {

	}

	@Override
	public void pause() {

	}

	@Override
	public void resume() {

	}

	@Override
	public void dispose() {
		batch.dispose();
		background.getTexture().dispose();
		
		stage.dispose();
		atlas.dispose();
		skin.dispose();
	}

}
