package net.eciz.evosciencia.util;

import java.util.HashMap;
import java.util.Map;

import net.eciz.evosciencia.model.DPADType;

import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.maps.tiled.TiledMapTileLayer;
import com.badlogic.gdx.math.Vector2;

public class CollisionDetector {
	
	private DPADType type;
	private int keyCode;
	private float x, y, tileWidth, tileHeight, totalMapWidth, totalMapHeight;
	private Vector2 velocity;
	private TiledMapTileLayer collisionLayer;
	
	public CollisionDetector(
			float tileWidth, 
			float tileHeight, 
			float totalMapWidth, 
			float totalMapHeight,
			TiledMapTileLayer collisionLayer ) {
		this.tileWidth = tileWidth;
		this.tileHeight = tileHeight;
		this.totalMapHeight = totalMapHeight;
		this.totalMapWidth = totalMapWidth;
		this.collisionLayer = collisionLayer;
	}

	public Map<String, Object> move(DPADType type, 
				float x, 
				float y,
				Vector2 velocity) {
		this.type = type;
		this.setX(x);
		this.setY(y);
		this.velocity = velocity;
		
		return this.moveObject();
	}
	
	public Map<String, Object> move(int keycode, 
			float x, 
			float y,
			Vector2 velocity) {
		this.keyCode = keycode;
		this.setX(x);
		this.setY(y);
		this.velocity = velocity;
		
		return this.moveObject();
	}
	
	public float getX() {
		return x;
	}

	public void setX(float x) {
		this.x = x;
	}

	public float getY() {
		return y;
	}

	public void setY(float y) {
		this.y = y;
	}

	private Map<String, Object> moveObject() {
		float x, y;
		Map<String, Object> returnValues = new HashMap<String, Object>();
		if( keyCode > 0 ) {
			switch(keyCode) {
				case Keys.W:
					y = getY() + (velocity.y);
		//			if( !collisionLayer.getCell((int) (getX()/tileWidth), (int) (y/tileHeight)).getTile().getProperties().containsKey("collision") ) 
						setY( y < totalMapHeight ? y : totalMapHeight );
					break;
				case Keys.S:
					y = getY() - (velocity.y);
		//			if( !collisionLayer.getCell((int) (getX()/tileWidth), (int) (y/tileHeight)).getTile().getProperties().containsKey("collision") )
						setY( y > 0 ? y : 0 );
					break;
				case Keys.A:
					x = getX() - (velocity.x);
		//			if( !collisionLayer.getCell((int) (x/tileWidth), (int) (getY()/tileHeight)).getTile().getProperties().containsKey("collision") )
						setX( x > 0 ? x : 0 );
					break;
				case Keys.D:
					x = getX() + (velocity.x);
		//			if( !collisionLayer.getCell((int) (x/tileWidth), (int) (getY()/tileHeight)).getTile().getProperties().containsKey("collision") )
						setX( x < totalMapWidth ? x : totalMapWidth);
					break;
			}
		
		} else {
			
			switch(type) {
				case DPAD_UP:
					y = getY() + (velocity.y);
	//				if( !collisionLayer.getCell((int) (getX()/tileWidth), (int) (y/tileHeight)).getTile().getProperties().containsKey("collision") ) 
						setY( y < totalMapHeight ? y : totalMapHeight );
					break;
				case DPAD_DOWN:
					y = getY() - (velocity.y);
	//				if( !collisionLayer.getCell((int) (getX()/tileWidth), (int) (y/tileHeight)).getTile().getProperties().containsKey("collision") )
						setY( y > 0 ? y : 0 );
					break;
				case DPAD_LEFT:
					x = getX() - (velocity.x);
	//				if( !collisionLayer.getCell((int) (x/tileWidth), (int) (getY()/tileHeight)).getTile().getProperties().containsKey("collision") )
						setX( x > 0 ? x : 0 );
					break;
				case DPAD_RIGHT:
					x = getX() + (velocity.x);
	//				if( !collisionLayer.getCell((int) (x/tileWidth), (int) (getY()/tileHeight)).getTile().getProperties().containsKey("collision") )
						setX( x < totalMapWidth ? x : totalMapWidth);
					break;
			}
			
		}
		
		returnValues.put("x", getX());
		returnValues.put("y", getY());
		returnValues.put("velocity", velocity);
		
		return returnValues;
	}
	
}
